==> igniteui-react-16.16.2.tgz: package/esm5/lib/Chip.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ChipVariant_$type } from "./ChipVariant";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
/**
 * @hidden
 */
var Chip = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Chip, _super);
    function Chip() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.remove = null;
        _this.select = null;
        return _this;
    }
    Object.defineProperty(Chip.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.d = this.k;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "g", {
        get: function () {
            var ret_ = this.f.c("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "h", {
        get: function () {
            var ret_ = this.f.c("removable");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("removable", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "i", {
        get: function () {
            var ret_ = this.f.c("selectable");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("selectable", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "j", {
        get: function () {
            var ret_ = this.f.c("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "a", {
        get: function () {
            var ret_ = this.f.c("variant");
            ret_ = enumGetBox(ChipVariant_$type, EnumUtil.getEnumValue(ChipVariant_$type, EnumUtil.parse(ChipVariant_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(ChipVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ChipVariant_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "d", {
        get: function () {
            var ret_ = this.f.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Chip.prototype.removeChanged = function () {
        var _this = this;
        if (this.remove != null) {
            this.f.g("remove", function (a) { return _this.remove(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.h("remove");
        }
    };
    Chip.prototype.selectChanged = function () {
        var _this = this;
        if (this.select != null) {
            this.f.g("select", function (a) { return _this.select(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.h("select");
        }
    };
    Chip.$t = markType(Chip, 'Chip', BaseElement.$);
    return Chip;
}(BaseElement));
export { Chip };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Chip.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ChipVariant_$type } from "./ChipVariant";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
/**
 * @hidden
 */
var Chip = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Chip, _super);
    function Chip() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.remove = null;
        _this.select = null;
        return _this;
    }
    Object.defineProperty(Chip.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    Chip.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Chip.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("removable");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("removable", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("selectable");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("selectable", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "a", {
        get: function () {
            var ret_ = this.f.n("variant");
            ret_ = enumGetBox(ChipVariant_$type, EnumUtil.getEnumValue(ChipVariant_$type, this.f.f(ChipVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ChipVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ChipVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Chip.prototype, "d", {
        get: function () {
            var ret_ = this.f.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Chip.prototype.removeChanged = function () {
        var _this = this;
        if (this.remove != null) {
            this.f.r("remove", function (a) { return _this.remove(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("remove");
        }
    };
    Chip.prototype.selectChanged = function () {
        var _this = this;
        if (this.select != null) {
            this.f.r("select", function (a) { return _this.select(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("select");
        }
    };
    Chip.$t = markType(Chip, 'Chip', BaseElement.$);
    return Chip;
}(BaseElement));
export { Chip };
